//
//  EpcViewController.m
//  AreteCapDongle
//
//  Created by 小田和哉 on 2016/02/15.
//
//

#import "EpcViewController.h"
#import "PhyUtility.h"
#import "ModelSettings.h"
#import "GlobalDefine.h"
#import "PhyUtility.h"
#import "Utils.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>

@interface EpcViewController ()<UITextViewDelegate, AsReaderRFIDDeviceDelegate>

@property (nonatomic, strong, readwrite) NSData *epc;
@property (nonatomic, strong, readwrite) NSData *pcEpc;
@property (weak, nonatomic) IBOutlet UITextField *targetLabel;
@property (weak, nonatomic) IBOutlet UITextView *inputText;
@property (weak, nonatomic) IBOutlet UITextField *inputHex;
@property (weak, nonatomic) IBOutlet UITextField *hexLabel;
@property (weak, nonatomic) IBOutlet UITextView *MyTextView;
@end

@implementation EpcViewController

#pragma mark - Lifecycle
//----------------------------------------------------------------
- (void)viewDidLoad
{
    [super viewDidLoad];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:NO];
    
    [AsReaderRFIDDevice sharedInstance].delegateRFID = self;
    
    ModelSettings *model = [ModelSettings sharedInstance];
    NSDictionary *dic = [model.m_arReadTagData objectAtIndex:model.m_nSelectTagNum];
    
    NSData *pcEpc = [dic objectForKey:df_CELL_TAG_RAW];
    self.epc = [pcEpc subdataWithRange:NSMakeRange(2, pcEpc.length - 2)];
    self.pcEpc = pcEpc;

    self.targetLabel.text = [self.epc bytesToHexString];;
    self.inputHex.text = [self.epc bytesToHexString];
    self.inputText.text = [self.epc bytesToCharString];
    self.MyTextView.text = @"";
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateRFID = nil;
}

#pragma mark - IBAction
//----------------------------------------------------------------
- (IBAction)done:(id)sender
{
    if ([self.inputText.text isEqualToString:@""]) {
        [Utils showAlert:@"" message:@"Please input Data." view:self];
        return;
    }
    
    NSLog(@"pcEpc:%@",self.pcEpc);
    [[AsReaderRFIDDevice sharedInstance] writeTagMemoryWithEPC:self.pcEpc dataToWriteAscii:self.inputText.text];
}

- (IBAction)changedHex:(id)sender
{
    self.inputText.text = [[self.inputHex.text hexStringToBytes] bytesToCharString];
}

- (IBAction)changedText:(id)sender
{
    self.inputHex.text = [[NSData dataWithBytes:[self.inputText.text UTF8String] length:[self.inputText.text length]] bytesToHexString];
}

- (IBAction)copyTarget:(id)sender
{
    self.targetLabel.text = self.hexLabel.text;
}

#pragma mark - AsReaderRFIDDeviceDelegate
//----------------------------------------------------------------
- (void)pcEpcReceived:(NSData *)pcEpc
{
    dispatch_async(dispatch_get_main_queue(), ^{
        NSLog(@"pcEpc:%@",pcEpc);
        self.pcEpc = pcEpc;
//        [NSThread sleepForTimeInterval:1.0f];
//       [self.rcp writeToTagMemory:pcEpc dataToWriteAscii:self.inputText.text];
        [[AsReaderRFIDDevice sharedInstance] readTagWithAccessPassword:0x00000000 epc:[self.inputText.text dataUsingEncoding:NSUTF8StringEncoding] memoryBank:0x01 startAddress:0x00 dataLength:0x00];
    });
}

- (void)writedReceived:(uint8_t)statusCode
{
    dispatch_async(dispatch_get_main_queue(), ^{
        [Utils showAlert:@"" message:@"Writed." view:self];
                
        [[AsReaderRFIDDevice sharedInstance] readTagWithAccessPassword:0x00000000 epc:[self.inputText.text dataUsingEncoding:NSUTF8StringEncoding] memoryBank:0x01 startAddress:0x00 dataLength:0x00];
    });
}

- (void)tagMemoryReceived:(NSData *)data
{
    dispatch_async(dispatch_get_main_queue(), ^{
        self.pcEpc = [data subdataWithRange:NSMakeRange(2, data.length - 2)];;
        self.epc = [data subdataWithRange:NSMakeRange(4, data.length - 4)];
        self.targetLabel.text = [self.epc bytesToHexString];
    });
}

#pragma mark - UITextView delegate
//----------------------------------------------------------------
-(BOOL)textView:(UITextView *)textView shouldChangeTextInRange:(NSRange)range replacementText:(NSString *)text
{
    self.inputHex.text = [[NSData dataWithBytes:[self.inputText.text UTF8String] length:[self.inputText.text length]] bytesToHexString];
    return YES;
}

#pragma mark - UIEvent
//----------------------------------------------------------------
- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event
{
    [self.targetLabel resignFirstResponder];
    [self.hexLabel resignFirstResponder];
    [self.inputText resignFirstResponder];
}

@end
